@@ -113,6 +113,7 @@ impl<'a> Parser<'a> {
             Token::Pipe | Token::Word | Token::Comma => self.text(context),
             Token::Eq => self.eat(),
             Token::Dollar => self.formula(),
+            Token::Href => self.eat(),
             Token::CommandName(name) => match name {
                 CommandName::Generic => self.generic_command(),
                 CommandName::BeginEnvironment if context.allow_environment => self.environment(),
@@ -158,6 +159,9 @@ impl<'a> Parser<'a> {
                 CommandName::EndBlockComment => self.generic_command(),
                 CommandName::VerbatimBlock => self.verbatim_block(),
                 CommandName::GraphicsPath => self.graphics_path(),
+                CommandName::BibItem => self.bibitem(),
+                CommandName::TocContentsLine => self.toc_contents_line(),
+                CommandName::TocNumberLine => self.toc_number_line(),
             },
         }
     }
@@ -862,7 +866,20 @@ impl<'a> Parser<'a> {
         }
 
         if self.lexer.peek() == Some(Token::LCurly) {
-            self.curly_group_word();
+            self.builder.start_node(CURLY_GROUP_WORD.into());
+            self.eat();
+            self.trivia();
+
+            if self.peek() == Some(Token::Word) || self.peek() == Some(Token::Pipe) {
+                self.key();
+            }
+
+            if let Some(Token::CommandName(_)) = self.peek() {
+                self.content(ParserContext::default());
+            }
+
+            self.expect(Token::RCurly);
+            self.builder.finish_node();
         }
 
         self.builder.finish_node();
@@ -1235,6 +1252,50 @@ impl<'a> Parser<'a> {
             }
         }
     }
+
+    fn bibitem(&mut self) {
+        self.builder.start_node(BIBITEM.into());
+        self.eat();
+        self.trivia();
+
+        if self.lexer.peek() == Some(Token::LCurly) {
+            self.curly_group_word();
+        }
+
+        self.builder.finish_node();
+    }
+
+    fn toc_contents_line(&mut self) {
+        self.builder.start_node(TOC_CONTENTS_LINE.into());
+        self.eat();
+        self.trivia();
+
+        if self.lexer.peek() == Some(Token::LCurly) {
+            self.curly_group();
+        }
+
+        if self.lexer.peek() == Some(Token::LCurly) {
+            self.curly_group();
+        }
+
+        if self.lexer.peek() == Some(Token::LCurly) {
+            self.curly_group();
+        }
+
+        self.builder.finish_node();
+    }
+
+    fn toc_number_line(&mut self) {
+        self.builder.start_node(TOC_NUMBER_LINE.into());
+        self.eat();
+        self.trivia();
+
+        if self.lexer.peek() == Some(Token::LCurly) {
+            self.curly_group();
+        }
+
+        self.builder.finish_node();
+    }
 }
 
 pub fn parse_latex(text: &str, config: &SyntaxConfig) -> GreenNode {
