@@ -12,7 +12,7 @@ pub fn small_range(node: &dyn AstNode<Language = LatexLanguage>) -> TextRange {
     let start = full_range.start();
     let mut token = node.syntax().last_token();
     while let Some(current) = token {
-        if !matches!(current.kind(), LINE_BREAK | WHITESPACE | COMMENT) {
+        if !matches!(current.kind(), WHITESPACE | COMMENT) {
             return TextRange::new(start, current.text_range().end());
         }
         token = current.prev_token();
@@ -233,7 +233,7 @@ impl Key {
         self.syntax()
             .children_with_tokens()
             .filter_map(|node| node.into_token())
-            .filter(|node| !matches!(node.kind(), WHITESPACE | LINE_BREAK | COMMENT))
+            .filter(|node| !matches!(node.kind(), WHITESPACE | COMMENT))
     }
 }
 
@@ -258,7 +258,7 @@ impl ToString for Key {
             .children_with_tokens()
             .filter_map(|node| node.into_token())
         {
-            if matches!(token.kind(), WHITESPACE | LINE_BREAK | COMMENT) {
+            if matches!(token.kind(), WHITESPACE | COMMENT) {
                 buf.push(' ');
             } else {
                 buf.push_str(token.text());
@@ -750,3 +750,43 @@ impl GraphicsPath {
         self.syntax().descendants().filter_map(CurlyGroupWord::cast)
     }
 }
+
+cst_node!(BibItem, BIBITEM);
+
+impl BibItem {
+    pub fn command(&self) -> Option<SyntaxToken> {
+        self.syntax().first_token()
+    }
+
+    pub fn name(&self) -> Option<CurlyGroupWord> {
+        self.syntax().children().find_map(CurlyGroupWord::cast)
+    }
+}
+
+cst_node!(TocContentsLine, TOC_CONTENTS_LINE);
+
+impl TocContentsLine {
+    pub fn command(&self) -> Option<SyntaxToken> {
+        self.syntax().first_token()
+    }
+
+    pub fn unit(&self) -> Option<CurlyGroup> {
+        self.syntax().children().find_map(CurlyGroup::cast)
+    }
+
+    pub fn line(&self) -> Option<CurlyGroup> {
+        self.syntax().children().filter_map(CurlyGroup::cast).nth(1)
+    }
+}
+
+cst_node!(TocNumberLine, TOC_NUMBER_LINE);
+
+impl TocNumberLine {
+    pub fn command(&self) -> Option<SyntaxToken> {
+        self.syntax().first_token()
+    }
+
+    pub fn number(&self) -> Option<CurlyGroup> {
+        self.syntax().children().find_map(CurlyGroup::cast)
+    }
+}
