@@ -19,7 +19,7 @@ use line_index::LineCol;
 use lsp_server::{Connection, ErrorCode, Message, RequestId};
 use lsp_types::{notification::*, request::*, *};
 use notify::event::ModifyKind;
-use notify_debouncer_full::{DebouncedEvent, Debouncer, FileIdMap};
+use notify_debouncer_full::{DebouncedEvent, Debouncer, RecommendedCache};
 use parking_lot::{Mutex, RwLock};
 use rustc_hash::FxHashSet;
 use serde::{de::DeserializeOwned, Serialize};
@@ -46,7 +46,7 @@ use self::{
 #[derive(Debug)]
 enum InternalMessage {
     SetDistro(Distro),
-    SetOptions(Options),
+    SetOptions(Box<Options>),
     FileEvent(Vec<DebouncedEvent>),
     Diagnostics,
     ChktexFinished(Url, Vec<diagnostics::Diagnostic>),
@@ -309,7 +309,9 @@ impl Server {
                         .parse_options(json.pop().expect("invalid configuration request"))
                         .unwrap();
 
-                    sender.send(InternalMessage::SetOptions(options)).unwrap();
+                    sender
+                        .send(InternalMessage::SetOptions(Box::new(options)))
+                        .unwrap();
                 }
                 Err(why) => {
                     log::error!("Retrieving configuration failed: {}", why);
@@ -545,8 +547,9 @@ impl Server {
     fn hover(&mut self, id: RequestId, mut params: HoverParams) -> Result<()> {
         normalize_uri(&mut params.text_document_position_params.text_document.uri);
         let uri_and_pos = &params.text_document_position_params;
+        let client_flags = Arc::clone(&self.client_flags);
         self.update_cursor(&uri_and_pos.text_document.uri, uri_and_pos.position);
-        self.run_query(id, move |db| hover::find(db, params));
+        self.run_query(id, move |db| hover::find(db, params, &client_flags));
         Ok(())
     }
 
@@ -700,19 +703,19 @@ impl Server {
 
                     let status = if pending_builds.lock().remove(&pid) {
                         if result?.success() {
-                            BuildStatus::SUCCESS
+                            BuildStatus::Success
                         } else {
-                            BuildStatus::ERROR
+                            BuildStatus::Error
                         }
                     } else {
-                        BuildStatus::CANCELLED
+                        BuildStatus::Cancelled
                     };
 
                     Ok(status)
                 })
                 .unwrap_or_else(|why| {
                     log::error!("Failed to compile document \"{uri}\": {why}");
-                    BuildStatus::FAILURE
+                    BuildStatus::Failure
                 });
 
             drop(progress_reporter);
@@ -723,7 +726,7 @@ impl Server {
                 let _ = client.send_response(lsp_server::Response::new_ok(id, result));
             }
 
-            if fwd_search_after && status != BuildStatus::CANCELLED {
+            if fwd_search_after && status != BuildStatus::Cancelled {
                 let _ = internal.send(InternalMessage::ForwardSearch(uri, params.position));
             }
         });
@@ -760,7 +763,7 @@ impl Server {
 
         self.pool.execute(move || {
             let status = match command.and_then(ForwardSearch::run) {
-                Ok(()) => ForwardSearchStatus::SUCCESS,
+                Ok(()) => ForwardSearchStatus::Success,
                 Err(why) => {
                     log::error!("Failed to execute forward search: {why}");
                     ForwardSearchStatus::from(why)
@@ -1071,7 +1074,7 @@ impl Server {
                             self.workspace.write().set_distro(distro);
                         }
                         InternalMessage::SetOptions(options) => {
-                            self.update_options(options);
+                            self.update_options(*options);
                         }
                         InternalMessage::FileEvent(events) => {
                             for event in events {
@@ -1121,7 +1124,7 @@ impl Server {
 }
 
 struct FileWatcher {
-    watcher: Debouncer<notify::RecommendedWatcher, FileIdMap>,
+    watcher: Debouncer<notify::RecommendedWatcher, RecommendedCache>,
     watched_dirs: FxHashSet<PathBuf>,
 }
 
@@ -1140,6 +1143,6 @@ impl FileWatcher {
     }
 
     pub fn watch(&mut self, workspace: &mut Workspace) {
-        deps::watch(workspace, self.watcher.watcher(), &mut self.watched_dirs);
+        deps::watch(workspace, &mut self.watcher, &mut self.watched_dirs);
     }
 }
